Installation
============

Stable release
--------------

To install PyPUMS, run this command in your terminal:

```shell
$ pip install pypums
```

This is the preferred method to install pypums, as it will always
install the most recent stable release.

If you don\'t have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

From sources
------------

The sources for pypums can be downloaded from the [Github repo](https://github.com/chekos/pypums).

You can either clone the public repository:

```shell
$ git clone git://github.com/chekos/pypums
```

Or download the
[tarball](https://github.com/chekos/pypums/tarball/master):

```shell
$ curl  -OL https://github.com/chekos/pypums/tarball/master
```

Once you have a copy of the source, you can install it with:

```shell
$ python setup.py install
```
